@@ -5,10 +5,10 @@ use strict;
 use warnings;
 
 use Error::Pure::Utils qw(err_helper);
-use List::MoreUtils qw(none);
+use List::Util qw(none);
 use Readonly;
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
@@ -147,7 +147,7 @@ Process error with message(s). There is key => value list after first message.
 =head1 DEPENDENCIES
 
 L<Exporter>,
-L<List::MoreUtils>,
+L<List::Util>,
 L<Readonly>.
 
 =head1 SEE ALSO
@@ -178,6 +178,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
