@@ -6,7 +6,7 @@ use warnings;
 
 use Error::Pure::Output::Text qw(err_print);
 use Error::Pure::Utils qw(err_helper);
-use List::MoreUtils qw(none);
+use List::Util qw(none);
 use Readonly;
 
 # Constants.
@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $EVAL => 'eval {...}';
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 # Process error.
 sub err {
@@ -127,7 +127,7 @@ Process error with message(s). There is key => value list after first message.
 L<Error::Pure::Output::Text>,
 L<Error::Pure::Utils>,
 L<Exporter>,
-L<List::MoreUtils>,
+L<List::Util>,
 L<Readonly>.
 
 =head1 SEE ALSO
@@ -158,6 +158,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
